0.95.2.cvs compilation succeeded on IRIX 6.5

Matthias Andree matthias.andree at gmx.de
Sat Aug 6 04:00:26 CEST 2005


On Sat, 06 Aug 2005, Daichi Kawahata wrote:

> > The logs have probably been stripped by the mailing list software,
> > it is configured not to let application/octet-stream pass. Try
> > text/plain for logs, or if the logs are larger, just upload them
> > to an FTP or HTTP server and tell us the URL or mail it offlist
> > to David and me.
> 
> Yeah, I've attached again (hope this works).

It did.

> configure:13914: checking for GSL - version >= 1.4
> configure:14013: ccache gcc -o conftest [...] -lgslcblas -lm >&5
> as ERROR parsing -no-mdebug:  unknown flag
> as ERROR parsing -mabi=n32:  unknown flag

This appears as though GCC assumed GNU as, and it got something else.

Might ccache induce these difficulties?

> configure:14016: $? = 1
> configure: program exited with status 1
> 
> > >  /** Type we use for a lock cell. */
> > > -typedef char cell_t;
> > > +typedef short cell_t;
> > > +/* typedef char cell_t; */
> > 
> > This looks problematic. Does "unsigned char" work for you?
> > Or what was the problem with cell_t being a "char"?
>  
> At error_on_irix.log, there seems type mismatch.

Right. I suggest we rename bogofilter's type from cell_t to bf_cell_t to
evade this clash, patch is attached. I wasn't aware IRIX has a "cell_t".

I have merged your configure.ac patch (that tells GSL MIPS doesn't have
extended precision FP). Thank you for your bug report, patch and help.

-- 
Matthias Andree
-------------- next part --------------
Index: src/db_lock.c
===================================================================
RCS file: /cvsroot/bogofilter/bogofilter/src/db_lock.c,v
retrieving revision 1.15
diff -u -r1.15 db_lock.c
--- src/db_lock.c	7 Jun 2005 11:08:42 -0000	1.15
+++ src/db_lock.c	5 Aug 2005 19:18:34 -0000
@@ -50,13 +50,13 @@
 #endif
 
 /** Type we use for a lock cell. */
-typedef char cell_t;
+typedef char bf_cell_t;
 
 /** Periodic check interval in seconds, for set_lock(). */
 static const int chk_intval = 30;
 /** String to append to base directory, for process table file. */
 static const char aprt[] = DIRSEP_S "lockfile-p";
 /** Size of a cell, must match sizeof(cell_t). */
 static const off_t cellsize = 1;
 /** Offset of our lock cell inside the lock file. */
 static off_t lockpos;
@@ -73,9 +73,9 @@
 static int lockfd = -1;
 
 /** Constant cell content for cells that are in use. */
-static const cell_t cell_inuse = '1';
+static const bf_cell_t cell_inuse = '1';
 /** Constant cell content for cells that are \b not in use. */
-static const cell_t cell_free = '0';
+static const bf_cell_t cell_free = '0';
 
 /** Save area for previous SIGALRM signal handler. */
 static struct sigaction oldact;
@@ -259,7 +259,7 @@
 static int check_zombies(void) {
     ssize_t r;
     off_t pos, savepos;
-    cell_t cell;
+    bf_cell_t cell;
 
     savepos = lseek(lockfd, 0, SEEK_CUR);
     if (savepos < 0)
@@ -325,7 +325,7 @@
 }
 
 int set_lock(void) {
-    cell_t cell;
+    bf_cell_t cell;
     ssize_t r;
 
     if (lseek(lockfd, 0, SEEK_SET) < 0)
@@ -50,13 +50,13 @@
 /** String to append to base directory, for process table file. */
 static const char aprt[] = DIRSEP_S "lockfile-p";
-/** Size of a cell, must match sizeof(cell_t). */
+/** Size of a cell, must match sizeof(bf_cell_t). */
 static const off_t cellsize = 1;
 /** Offset of our lock cell inside the lock file. */


More information about the Bogofilter mailing list